/* GNU mailutils - a suite of utilities for electronic mail
   Copyright (C) 1999, 2000, 2001, 2007 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */

#ifndef _ARGCV_H
# define _ARGCV_H 1

# include <stdio.h>
# include <stdlib.h>
# include <unistd.h>
# include <string.h>

# ifdef __cplusplus
extern "C"
{
# endif

  extern int argcv_get (const char *command, const char *delim,
			int *argc, char ***argv);
  extern int argcv_string (int argc, char **argv, char **string);
  extern int argcv_free (int argc, char **argv);

# ifdef __cplusplus
}
# endif

#endif				/* _ARGCV_H */
